@@ -1,5 +1,8 @@
+#' @export
+#' @rdname qvcalc
 qvcalc.itempar <- function(object, ...){
-  if (!(attr(object, "alias"))) stop(
+  alias = attr(object, "alias")
+  if (!isTRUE(alias)) stop(
                   "the itempar object was not built with 'alias = TRUE'")
   vc <- vcov(object)
   if (any(is.na(vc))) stop("the itempar object was not built with 'vcov = TRUE'")
